@@ -14,6 +14,11 @@ class Api(object):
         """
         raise NotImplementedError
 
+    def set_port_capture(self, content):
+        """TBD
+        """
+        raise NotImplementedError
+
     def set_flow_transmit(self, content):
         """TBD
         """
@@ -29,6 +34,11 @@ class Api(object):
         """
         raise NotImplementedError
 
+    def get_capture_results(self, content):
+        """TBD
+        """
+        raise NotImplementedError
+
     def get_flow_results(self, content):
         """TBD
         """
